### Before submitting

Please complete the following checklist when submitting a PR:

- [ ] I have added UnitTests for my submitted code. 

- [ ] I have added appropriate docstring and inline comments for readability and
      building documentation.

- [ ] I have run `checks.sh` and it passes all tests with `pylint` not less than 9.5.

When all the above are checked, delete everything above the dashed
line and fill in the pull request template.

------------------------------------------------------------------------------------------------------------

**Context:**

**Description:**

**Advantages:**

**Side Effects:**

**Related GitHub Issues:**
